This is an automated email from the ASF dual-hosted git repository.

xiaoxiang pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/nuttx.git

commit 3622e4830a8d38b93dfef008c946a3061fcbf5a7
Author: ouyangxiangzhen <ouyangxiangz...@xiaomi.com>
AuthorDate: Thu May 8 19:47:02 2025 +0800

    sched: Correct word spelling mistakes.
    
    This commit fixed serveral word spelling mistakes.
    
    Signed-off-by: ouyangxiangzhen <ouyangxiangz...@xiaomi.com>
---
 include/nuttx/clock.h                |  2 +-
 libs/libc/time/lib_daysbeforemonth.c | 10 +++++-----
 sched/Kconfig                        |  6 +++---
 sched/group/group_continue.c         |  2 +-
 sched/sched/sched_timerexpiration.c  |  2 +-
 sched/signal/sig_timedwait.c         |  4 ++--
 6 files changed, 13 insertions(+), 13 deletions(-)

diff --git a/include/nuttx/clock.h b/include/nuttx/clock.h
index e64f3fee6c..8230c8c2b4 100644
--- a/include/nuttx/clock.h
+++ b/include/nuttx/clock.h
@@ -571,7 +571,7 @@ int clock_isleapyear(int year);
  *
  ****************************************************************************/
 
-int clock_daysbeforemonth(int month, bool leapyear);
+int clock_daysbeforemonth(int month, bool leap_year);
 
 /****************************************************************************
  * Name:  clock_dayoftheweek
diff --git a/sched/Kconfig b/sched/Kconfig
index 840871b26a..81f226c1ce 100644
--- a/sched/Kconfig
+++ b/sched/Kconfig
@@ -1179,7 +1179,7 @@ config SCHED_PROFILE_TICKSPERSEC
        int "Profile sampling rate"
        default 1000
        ---help---
-               This is the frequency at which the profil functon will sample 
the
+               This is the frequency at which the profil function will sample 
the
                running program. The default is 1000Hz.
 
 menuconfig SCHED_INSTRUMENTATION
@@ -2000,11 +2000,11 @@ config SCHED_EVENTS
                events to event objects.
 
 config ASSERT_PAUSE_CPU_TIMEOUT
-       int "Timeout in milisecond to pause another CPU when assert"
+       int "Timeout in millisecond to pause another CPU when assert"
        default 2000
        depends on SMP
        ---help---
-               Timeout in milisecond to pause another CPU when assert. Only 
available
+               Timeout in millisecond to pause another CPU when assert. Only 
available
                when SMP is enabled.
                Enable to support perf events.
 
diff --git a/sched/group/group_continue.c b/sched/group/group_continue.c
index 0c6c6a3624..70f9c508b8 100644
--- a/sched/group/group_continue.c
+++ b/sched/group/group_continue.c
@@ -67,7 +67,7 @@ static int group_continue_handler(pid_t pid, FAR void *arg)
   rtcb = nxsched_get_tcb(pid);
   if (rtcb != NULL)
     {
-      /* Remove the task from waitting list */
+      /* Remove the task from waiting list */
 
       nxsched_remove_blocked(rtcb);
 
diff --git a/sched/sched/sched_timerexpiration.c 
b/sched/sched/sched_timerexpiration.c
index 6fe5ba0b35..b28180c26a 100644
--- a/sched/sched/sched_timerexpiration.c
+++ b/sched/sched/sched_timerexpiration.c
@@ -410,7 +410,7 @@ static clock_t nxsched_timer_start(clock_t ticks, clock_t 
interval)
       /* Normally, timer event cannot triggered on exact time
        * due to the existence of interrupt latency.
        * Assuming that the interrupt latency is distributed within
-       * [Best-Case Execution Time, Worst-Case Excution Time],
+       * [Best-Case Execution Time, Worst-Case Execution Time],
        * we can set the timer adjustment value to the BCET to
        * reduce the latency.
        * After the adjustment, the timer interrupt latency will be
diff --git a/sched/signal/sig_timedwait.c b/sched/signal/sig_timedwait.c
index 22cd6bd160..dec5ea3776 100644
--- a/sched/signal/sig_timedwait.c
+++ b/sched/signal/sig_timedwait.c
@@ -113,7 +113,7 @@ static void nxsig_timeout(wdparm_t arg)
 #endif
         }
 
-      /* Remove the task from waitting list */
+      /* Remove the task from waiting list */
 
       dq_rem((FAR dq_entry_t *)wtcb, list_waitingforsignal());
 
@@ -183,7 +183,7 @@ void nxsig_wait_irq(FAR struct tcb_s *wtcb, int errcode)
 #endif
         }
 
-      /* Remove the task from waitting list */
+      /* Remove the task from waiting list */
 
       dq_rem((FAR dq_entry_t *)wtcb, list_waitingforsignal());
 

Reply via email to
diff --git a/libs/libc/time/lib_daysbeforemonth.c 
b/libs/libc/time/lib_daysbeforemonth.c
index 65334c5686..6ed303444f 100644
--- a/libs/libc/time/lib_daysbeforemonth.c
+++ b/libs/libc/time/lib_daysbeforemonth.c
@@ -52,19 +52,19 @@ static const uint16_t g_daysbeforemonth[13] =
  *    month.
  *
  * Input Parameters:
  *    month    - The month in the form of tm_mon, that is a range of 0-11.
  *    leapyear - True if leap year and there are 29 days in February.
  *               NOTE the month=1 is February.
  *
  * Returned Value:
  *    The number of days that occurred before the month
  *
  ****************************************************************************/
 
-int clock_daysbeforemonth(int month, bool leapyear)
+int clock_daysbeforemonth(int month, bool leap_year)
 {
   int retval = g_daysbeforemonth[month];
-  if (month >= 2 && leapyear)
+  if (month >= 2 && leap_year)
     {
       retval++;
     }
@@ -52,19 +52,19 @@ static const uint16_t g_daysbeforemonth[13] =
  *
  * Input Parameters:
- *    month    - The month in the form of tm_mon, that is a range of 0-11.
- *    leapyear - True if leap year and there are 29 days in February.
- *               NOTE the month=1 is February.
+ *    month     - The month in the form of tm_mon, that is a range of 0-11.
+ *    leap_year - True if leap year and there are 29 days in February.
+ *                NOTE the month=1 is February.
  *
  * Returned Value: